# SAP Suggestions in Reports
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports#prerequisites)
  * [Available Reports](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports#available-reports)
  * [Enabling SAP Suggestions](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports#enabling-sap-suggestions)
  * [Displaying SAP Suggestions](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports#displaying-sap-suggestions)
  * [Viewing SAP Suggestions in Reports](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports#viewing-sap-suggestions-in-reports)
  * [Creating Fact Sheets from SAP Suggestions](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports#creating-fact-sheets-from-sap-suggestions)
  * [Using SAP Suggestions for Strategic Planning and Optimization](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports#using-sap-suggestions-for-strategic-planning-and-optimization)


View SAP suggestions for AI agents and applications in reports. Create fact sheets from relevant suggestions.
